<?php
namespace HCM\Geral\Services;

use HCM\Geral\Repository\AprovacaoAdmissaoRepository;
use HCM\Util\Repositories;
use Doctrine\ORM\EntityManager;
use HCM\Util\HCMParameters;
use HCM\Util\Messages;
use HCM\Util\DateUtil;
use Zeedhi\Framework\DTO;

class AprovacaoAdmissaoService {

    public function __construct(EntityManager $entityManager, HCMParameters $hcmParameters, AprovacaoAdmissaoRepository $aprovacaoAdmissaoRepository) {
        $this->entityManager = $entityManager;
        $this->hcmParameters = $hcmParameters;
        $this->aprovacaoAdmissaoRepository = $aprovacaoAdmissaoRepository;
    }
    
    public function getVinculosNaoAprovados($parameters, $conditions){
        return $this->aprovacaoAdmissaoRepository->getVinculosNaoAprovados($parameters, $conditions);
    }
    
    public function getPessoasNaoAprovadas($parameters, $conditions){
        return $this->aprovacaoAdmissaoRepository->getPessoasNaoAprovadas($parameters, $conditions);
    }
    
    public function aprovaAdmissao($row){
        try{
            $campos = array();
            
            //Valida campos obrigatórios para aprovação da admissão
            if (is_null($row['NMVINCULOM']) || $row['NMVINCULOM'] == "") {
                $campos[] = "Nome";
            }
            if (is_null($row['NRTIPOVINCULOM']) || $row['NRTIPOVINCULOM'] == "") {
                $campos[] = "Tipo Vínculo";
            }
            if (is_null($row['NRVINCULOEMPREG']) || $row['NRVINCULOEMPREG'] == "") {
                $campos[] = "Vínculo Empregatício";
            }
            if (is_null($row['DTADMISSAOVINC']) || $row['DTADMISSAOVINC'] == "") {
                $campos[] = "Data de Admissão";
            }
            if (is_null($row['NMTPADMISSAO']) || $row['NMTPADMISSAO'] == "") {
                $campos[] = "Tipo de Admissão";
            }
            if (is_null($row['DTOPCAOFGTS']) || $row['DTOPCAOFGTS'] == "") {
                $campos[] = "Opção FGTS";
            }
            if (is_null($row['DSTPREGIMEPREV']) || $row['DSTPREGIMEPREV'] == "") {
                $campos[] = "Tipo de Regime da Previdência";
            }
            //Dados Pessoais
            if (is_null($row['NRRGPESSOA']) || $row['NRRGPESSOA'] == "") {
                $campos[] = "RG";
            }
            if (is_null($row['NMPAISNATURALI']) || $row['NMPAISNATURALI'] == "") {
                $campos[] = "País";
            }
            //Endereço
            if (is_null($row['NMPAIS']) || $row['NMPAIS'] == "") {
                $campos[] = "País";
            }
            if (is_null($row['NMMUNICIPIO']) || $row['NMMUNICIPIO'] == "") {
                $campos[] = "Município";
            }
            if (is_null($row['NMBAIRROENDERECO']) || $row['NMBAIRROENDERECO'] == "") {
                $campos[] = "Bairro";
            }
            //Ocupação
            if (is_null($row['NMCARGO']) || $row['NMCARGO'] == "") {
                $campos[] = "Cargo";
            }
            //Escala de Trabalho
            if (is_null($row['NMESCALATRABH']) || $row['NMESCALATRABH'] == "") {
                $campos[] = "Escala Trabalho";
            }
            if (is_null($row['DTINIESCALA']) || $row['DTINIESCALA'] == "") {
                $campos[] = "Dt. Início";
            }
            //Estruturas
            if (is_null($row['NMESTRUTGEREN']) || $row['NMESTRUTGEREN'] == "") {
                $campos[] = "Estrutura Gerencial";
            }
            if (is_null($row['NMESTRUTLEGAL']) || $row['NMESTRUTLEGAL'] == "") {
                $campos[] = "Estrutura Legal";
            }
            //Salário
            if (is_null($row['NROCORRENCIA']) || $row['NROCORRENCIA'] == "") {
                $campos[] = "Nr. Ocorrência";
            }
            if (is_null($row['DSTIPOSALARIO']) || $row['DSTIPOSALARIO'] == "") {
                $campos[] = "Tipo Salário";
            }
            if (is_null($row['VRSALARIO']) || $row['VRSALARIO'] == "") {
                $campos[] = "Salário";
            }
            
            if (empty($campos)) {
                try {
                $this->entityManager->beginTransaction();
    
                $vinculoh = $this->entityManager->getRepository(Repositories::GPE_VINCULOH)->findOneBy(array('nrvinculom' => $row['NRVINCULOM'], 'nrorg' => $row['NRORG'], 'dtmescompetenc' => DateUtil::getDataDeString(substr($row['DTMESCOMPETENC'], 0, 10), DateUtil::FORMATO_BRASILEIRO, true)));
                $vinculoh->setDtmescompetenc(DateUtil::truncateData(DateUtil::getPrimeiroDiaDoMes(DateUtil::getDataDeString(substr($row['DTADMISSAOVINC'],0,10), DateUtil::FORMATO_BRASILEIRO, true))));
                $vinculoh->setNrorgultatu($this->hcmParameters->getNrorgTrabalho());         
                $vinculoh->setCdoperultatu($this->hcmParameters->getCdoperador());
                $vinculoh->setDtultatu(DateUtil::getDataAtual());
            
    			$this->entityManager->persist($vinculoh);
    			$this->entityManager->flush($vinculoh);
            
                $this->entityManager->commit();
                } catch(Exception $e) {
                    $this->entityManager->rollback();
                    throw $e;
                }
            } else {
                throw new \Exception("Favor informar os campos obrigatórios no vínculo " . $row['NRVINCULOM'] . ": " . implode(', ',$campos));
            }
        }catch(\Exception $e){
            throw $e;
        }
    }
    
    public function aprovaAdmissaoPessoa($row) {
        try {
            $msg = $row['NMPESSOA'].' (CPF '.$row['NRCPFPESSOA'].')';
            
            if($row['DTADMISSAOPRE'] == null) //Se a data de admissão preliminar não for preenchida este aborta.
                return array('msg' => $msg, 'type' => DTO\Response\Message::TYPE_ERROR);
            
            $this->entityManager->beginTransaction();
            
            $pessoah = $this->entityManager->getRepository(Repositories::GPE_PESSOAH)->findOneBy(array(
                'nrorg'     => $row['NRORG'],
                'nrpessoah' => $row['NRPESSOAH']
                ));
                
            $pessoah->setDtmescompetenc(DateUtil::truncateData(DateUtil::getPrimeiroDiaDoMes(DateUtil::getDataDeString(substr($row['DTADMISSAOPRE'],0,10)), DateUtil::FORMATO_BRASILEIRO, true)));
            
            $pessoah->setNrorgultatu($this->hcmParameters->getNrorgTrabalho());         
            $pessoah->setCdoperultatu($this->hcmParameters->getCdoperador());
            $pessoah->setDtultatu(DateUtil::getDataAtual());
            
            $this->entityManager->persist($pessoah);
			$this->entityManager->flush($pessoah);
			
            $this->entityManager->commit();
        } catch(Exception $e){
            $this->entityManager->rollback();
            throw $e;
        }
        return array('msg' => $msg, 'type' => DTO\Response\Message::TYPE_MESSAGE);
    }
    
    public function setAlteracoesAprova($row){
        try{
            $this->entityManager->beginTransaction();
            // atualiza vinculo
            $vinculom = $this->entityManager->getRepository(Repositories::GPE_VINCULOM)->findOneBy(array("nrvinculom" => $row['NRVINCULOM'], "nrorg" => $row['NRORG']));
            $vinculoh = $this->entityManager->getRepository(Repositories::GPE_VINCULOH)->findOneBy(array('nrvinculom' => $row['NRVINCULOM'], 'nrorg' => $row['NRORG'], 'dtmescompetenc' => DateUtil::getDataDeString(substr($row['DTMESCOMPETENC'], 0, 10), DateUtil::FORMATO_BRASILEIRO, true)));
            $vinculom->setNmvinculom($row['NMVINCULOM']);
            $vinculom->setNrtipovinculom($row['NRTIPOVINCULOM']);
            $vinculom->setNrvinculoempreg($row['NRVINCULOEMPREG']);
            $vinculom->setDtexamemedico(DateUtil::getDataDeString2($row['DTEXAMEMEDICO'], DateUtil::FORMATO_BRASILEIRO, true));
            $vinculom->setNrtpadmissao($row['NRTPADMISSAO']);
            $vinculom->setDtopcaofgts(DateUtil::getDataDeString2($row['DTOPCAOFGTS'], DateUtil::FORMATO_BRASILEIRO, true));
            $vinculom->setDtentregaepi(DateUtil::getDataDeString2($row['DTENTREGAEPI'], DateUtil::FORMATO_BRASILEIRO, true));
            $vinculom->setNrdiasapurvales($row['NRDIASAPURVALES']);
            $vinculom->setIdsegdesempvinc($row['IDSEGDESEMPVINC']);
            $vinculom->setDtaposentafgts(DateUtil::getDataDeString2($row['DTAPOSENTAFGTS'], DateUtil::FORMATO_BRASILEIRO, true));
            $vinculom->setNrdiascontratoexp($row['NRDIASCONTRATOEXP']);
            $vinculom->setNrdiascontratoexppro($row['NRDIASCONTRATOEXPPRO']);
            $vinculom->setDslivroadmissao($row['DSLIVROADMISSAO']);
            $vinculom->setNrclausassecurat($row['NRCLAUSASSECURAT']);
            $vinculom->setDtvenccontrexper(DateUtil::getDataDeString($row['DTVENCCONTREXPER'], DateUtil::FORMATO_BRASILEIRO, true));
            $vinculom->setNrmotivoadmissao($row['NRMOTIVOADMISSAO']);
            $vinculom->setNrvinculomsubst($row['NRVINCULOMSUBST']);
            $vinculom->setNrorgultatu($this->hcmParameters->getNrorgTrabalho());         
            $vinculom->setCdoperultatu($this->hcmParameters->getCdoperador());
            $vinculom->setDtultatu(DateUtil::getDataAtual()); 
            
            $vinculoh->setIdcontribuisind($row['IDCONTRIBUISIND']);
            $vinculoh->setDtfimcontrdetermin(DateUtil::getDataDeString2($row['DTFIMCONTRDETERMIN'], DateUtil::FORMATO_BRASILEIRO, true));
            $vinculoh->setDtbaseferias(DateUtil::getDataDeString2($row['DTBASEFERIAS'], DateUtil::FORMATO_BRASILEIRO, true));
            $vinculoh->setIdmultvinc($row['IDMULTVINC']);
            $vinculoh->setNrtpmovtransfm($row['NRTPMOVTRANSFM']);
            $vinculoh->setIdremuneracao($row['IDREMUNERACAO']);
            $vinculoh->setIdtppagamento($row['IDTPPAGAMENTO']);
            $vinculoh->setCdcontribindividual($row['CDCONTRIBINDIVIDUAL']);
            $vinculoh->setNrtpmodalidsal($row['NRTPMODALIDSAL']);
            $vinculoh->setNrtpregimeprev($row['NRTPREGIMEPREV']);
            $vinculoh->setIdpagpropfer13($row['IDPAGPROPFER13']);
            $vinculoh->setNrorgultatu($this->hcmParameters->getNrorgTrabalho());         
            $vinculoh->setCdoperultatu($this->hcmParameters->getCdoperador());
            $vinculoh->setDtultatu(DateUtil::getDataAtual()); 
            
            // atualiza pessoa
            $pessoa = $this->entityManager->getRepository(Repositories::GPE_PESSOA)->findOneBy(array('nrorg' => $row['NRORG'], 'nrpessoa' => $row['NRPESSOA']));
            $pessoah = $this->entityManager->getRepository(Repositories::GPE_PESSOAH)->findOneBy(array('nrorg' => $row['NRORG'], 'nrpessoa' => $row['NRPESSOA']));
            $pessoah = $this->setPessoah($pessoah, $row);
            $this->entityManager->persist($pessoah);
			$this->entityManager->flush($pessoah);
            
            // atualiza endereço
            $endereco = $this->entityManager->getRepository(Repositories::ENDERECOPARC)->findOneBy(array('nrparcnegocio' => $pessoa->getNrparcnegocio(), 'nrorg' => $row['NRORG'], 'cdtipoendereco' => 'PRINCIPAL'));
            $endereco = $this->setEndereco($endereco, $row);
            $this->entityManager->persist($endereco);
			$this->entityManager->flush($endereco);
            
            // atualiza forma de comunicação
            $telefone = $this->entityManager->getRepository(Repositories::COMUNICAPARC)->findOneBy(array('nrparcnegocio' => $pessoa->getNrparcnegocio(), 'nrorg' => $row['NRORG'], 'cdformacomu' =>'01'));
            if($row['NRTELEFONE']){
                $telefone = $this->setTelefone($telefone, $row, $pessoa->getNrparcnegocio());
                $this->entityManager->persist($telefone);
    			$this->entityManager->flush($telefone);
            }else{
                if($telefone){
                    $this->entityManager->remove($telefone);
                    $this->entityManager->flush();
                }
            }
            $email = $this->entityManager->getRepository(Repositories::COMUNICAPARC)->findOneBy(array('nrparcnegocio' => $pessoa->getNrparcnegocio(), 'nrorg' => $row['NRORG'], 'cdformacomu' =>'05'));
            if($row['DSEMAIL']){
                $email = $this->setEmail($email, $row, $pessoa->getNrparcnegocio());
                $this->entityManager->persist($email);
                $this->entityManager->flush();
            }else{
                if($email){
                    $this->entityManager->remove($email);
                    $this->entityManager->flush();
                }
            }
            
            // atualiza conta corrente
            $contacorr = $this->entityManager->getRepository(Repositories::CONTCORRPARC)->findOneBy(array('nrparcnegocio' => $pessoa->getNrparcnegocio(), 'nrorg' => $row['NRORG']));
            if($row['CDBANCO']){
                $contacorr = $this->setContCorr($contacorr, $row, $pessoa->getNrparcnegocio());
                $this->entityManager->persist($contacorr);
    			$this->entityManager->flush($contacorr);    
            }else{
                if($contacorr){
                    $this->entityManager->remove($contacorr);
                    $this->entityManager->flush();
                }
            }
            
            // atualiza ocupação
            $alteOcupacao = $this->entityManager->getRepository(Repositories::GPE_ALTEOCUPACAO)->findOneBy(array('nrvinculom' => $row['NRVINCULOM'], 'nrorg' => $row['NRORG']));
            if($alteOcupacao->getNrocupacaom() != $row['NRCARGO']){
                $alteOcupacao->setNrocupacaom($row['NRCARGO']);
                $vinculoh->setNrcargo($row['NRCARGO']);
    			$this->entityManager->flush($alteOcupacao);    
                $this->entityManager->persist($alteOcupacao);
            }
            if($vinculoh->getNrfuncao() != $row['NRFUNCAO']){
                $vinculoh->setNrfuncao($row['NRFUNCAO']);
            }
            
            // atualiza escala de trabalho
            $alteEscala = $this->entityManager->getRepository(Repositories::GPE_ALTEESCALA)->findOneBy(array('nrvinculom' => $row['NRVINCULOM'], 'nrorg' => $row['NRORG']));
            if($alteEscala){
                $alteEscala->setNrescalatrabm($row['NRESCALATRABM']);
                $alteEscala->setNrturno($row['NRTURNO']);
                $alteEscala->setQthrlimitesephextra($row['QTHRLIMITESEPHEXTRA']);
                $alteEscala->setDtiniescala(DateUtil::getDataDeString2($row['DTINIESCALA'], DateUtil::FORMATO_BRASILEIRO, true));
                $alteEscala->setDtfimescala(DateUtil::getDataDeString2($row['DTFIMESCALA'], DateUtil::FORMATO_BRASILEIRO, true));
            }else{
                $novoItem = Repositories::GPE_ALTEESCALA;
                $alteEscala = new $novoItem();
                $alteEscala->setNralteescala(\HCM\Util\NovoCodigo::geraCodigo($this->hcmParameters->getNrorgTrabalho(), 'GPE_ALTEESCALA', 1, 12, true));
                $alteEscala->setNrvinculom($vinculom->getNrvinculom());                
                $alteEscala->setNrescalatrabm($row['NRESCALATRABM']);             
                $alteEscala->setNrturno($row['NRTURNO']);
                $alteEscala->setQthrlimitesephextra($row['QTHRLIMITESEPHEXTRA']);
                $alteEscala->setDtiniescala(DateUtil::getDataDeString($row['DTINIESCALA'], DateUtil::FORMATO_BRASILEIRO, true));
                $alteEscala->setDtfimescala(DateUtil::getDataDeString($row['DTFIMESCALA'], DateUtil::FORMATO_BRASILEIRO, true)); 
                $alteEscala->setNrorg($row['NRORG']);                     
                $alteEscala->setDtinclusao(DateUtil::getDataAtual());           
                $alteEscala->setNrorginclusao($this->hcmParameters->getNrorgTrabalho());         
                $alteEscala->setCdoperinclusao($this->hcmParameters->getCdoperador());   
                $alteEscala->setNrorgultatu($this->hcmParameters->getNrorgTrabalho());         
                $alteEscala->setCdoperultatu($this->hcmParameters->getCdoperador());
                $alteEscala->setDtultatu(DateUtil::getDataAtual()); 
            }
            $vinculoh->setNrescalatrabm($row['NRESCALATRABM']);
            $vinculoh->setNrturno($row['NRTURNO']);   
            $this->entityManager->persist($alteEscala);
			$this->entityManager->flush($alteEscala); 
			
            // atualiza estruturas
            $movimentLegal = $this->entityManager->getRepository(Repositories::GPE_MOVIMENTACAO)->findOneBy(array('nrvinculom' => $row['NRVINCULOM'], 'nrorg' => $row['NRORG'], 'nrtipotransfer' => 1, 'nrtipoestrutura' => $this->hcmParameters->getTipoEstruturaLegalOrg()));
            $movimentLegal->setNrestruturam($row['NRESTRUTLEGAL']);
            $vinculoh->setNrestrutlegal($row['NRESTRUTLEGAL']);
            $this->entityManager->persist($movimentLegal);
			$this->entityManager->flush($movimentLegal);    
            
            $movimentGeren = $this->entityManager->getRepository(Repositories::GPE_MOVIMENTACAO)->findOneBy(array('nrvinculom' => $row['NRVINCULOM'], 'nrorg' => $row['NRORG'], 'nrtipotransfer' => 2, 'nrtipoestrutura' => $this->hcmParameters->getTipoEstruturaGerencialOrg()));
            $movimentGeren->setNrestruturam($row['NRESTRUTGEREN']);
            $this->entityManager->persist($movimentGeren);
			$this->entityManager->flush($movimentGeren);
			
            $movimentSind = $this->entityManager->getRepository(Repositories::GPE_MOVIMENTACAO)->findOneBy(array('nrvinculom' => $row['NRVINCULOM'], 'nrorg' => $row['NRORG'], 'nrtipotransfer' => 1, 'nrtipoestrutura' => 10));
            if($row['NRESTRUTSIND']){
                if($movimentSind){
                    $movimentSind->setNrestruturam($row['NRESTRUTSIND']);
                    $vinculoh->setNrestrutsind($row['NRESTRUTSIND']);
                    $this->entityManager->persist($movimentSind);
        			$this->entityManager->flush($movimentSind);
                }else{
                    $novoItem = Repositories::GPE_MOVIMENTACAO;
                    $novoItem = new $novoItem();
                    $novoItem->setNrmovimentacao(\HCM\Util\NovoCodigo::geraCodigo($this->hcmParameters->getNrorgTrabalho(), 'GPE_MOVIMENTACAO', 1, 12, true));            
                    $novoItem->setNrvinculom($vinculom->getNrvinculom());                
                    $novoItem->setNrestruturam($row['NRESTRUTSIND']);             
                    $novoItem->setDtinimoviment(DateUtil::getDataDeString(substr($row['DTADMISSAOVINC'],0,10), DateUtil::FORMATO_BRASILEIRO, true)); 
                    $novoItem->setNrorg($row['NRORG']);                     
                    $novoItem->setNrtipotransfer(1); 
                    $novoItem->setNrtipoestrutura(10);
                    $novoItem->setDtinclusao(DateUtil::getDataAtual());           
                    $novoItem->setNrorginclusao($this->hcmParameters->getNrorgTrabalho());         
                    $novoItem->setCdoperinclusao($this->hcmParameters->getCdoperador());   
                    $novoItem->setNrorgultatu($this->hcmParameters->getNrorgTrabalho());         
                    $novoItem->setCdoperultatu($this->hcmParameters->getCdoperador());
                    $novoItem->setDtultatu(DateUtil::getDataAtual()); 
                    $vinculoh->setNrestrutsind($row['NRESTRUTSIND']);
                }     
            }else{
                if($movimentSind){
                    $this->entityManager->remove($contacorr);
                    $this->entityManager->flush();
                    $vinculoh->setNrestrutsind();
                } 
                
            }
            
            // atualiza salário
            $alteSalario = $this->entityManager->getRepository(Repositories::GPE_ALTESALARIO)->findOneBy(array('nrvinculom' => $row['NRVINCULOM'], 'nrorg' => $row['NRORG']));
            $alteSalario->setNrocorrencia($row['NROCORRENCIA']);
            $alteSalario->setIdtpsalario($row['IDTPSALARIO']);
            $alteSalario->setVrsalario($this->validaValorMonetario($row['VRSALARIO']));
            $this->entityManager->persist($alteSalario);
			$this->entityManager->flush($alteSalario);
			
			$this->entityManager->persist($vinculom);
			$this->entityManager->flush($vinculom);
			$this->entityManager->persist($vinculoh);
			$this->entityManager->flush($vinculoh);
        
            $this->entityManager->commit();
        }catch(Exception $e){
            $this->entityManager->rollback();
            throw $e;
        }
    }
    
    public function setEndereco($endereco, $row){
        if($endereco){
            $endereco->setCdpais($row['CDPAIS']);    
            $endereco->setSgestado($row['SGESTADO']);    
            $endereco->setCdmunicipio($row['CDMUNICIPIO']);    
            $endereco->setCdlogradouro($row['CDLOGRADOURO']);    
            $endereco->setNmbairroendereco($row['NMBAIRROENDERECO']);  
            $endereco->setDscompleendereco($row['DSCOMPLEENDERECO']);  
            $endereco->setNrcependereco($row['NRCEPENDERECO']);   
            $endereco->setDsreferenciaende($row['DSREFERENCIAENDE']); 
            $endereco->setDsendereco($row['DSENDERECO']);
            $endereco->setNrimovelendereco($row['NRIMOVELENDERECO']);
            $endereco->setNrorgultatu($this->hcmParameters->getNrorgTrabalho());         
            $endereco->setCdoperultatu($this->hcmParameters->getCdoperador());
            $endereco->setDtultatu(DateUtil::getDataAtual()); 
            return $endereco;
        }else{
            $novoItem = Repositories::ENDERECOPARC;
            $novoItem = new $novoItem();
            $novoItem->setNrenderecoparc(\HCM\Util\NovoCodigo::geraCodigo($this->hcmParameters->getNrorgTrabalho(), 'ENDERECOPARC', 1, 12, true));         
            $novoItem->setNrparcnegocio($row['NRPARCNEGOCIO']);         
            $novoItem->setCdtipoendereco('PRINCIPAL');   
            $novoItem->setNrorg($row['NRORG']);
            $novoItem->setIdativo('S');
            $novoItem->setCdpais($row['CDPAIS']);    
            $novoItem->setSgestado($row['SGESTADO']);    
            $novoItem->setCdmunicipio($row['CDMUNICIPIO']);    
            $novoItem->setCdlogradouro($row['CDLOGRADOURO']);    
            $novoItem->setNmbairroendereco($row['NMBAIRROENDERECO']);  
            $novoItem->setDscompleendereco($row['DSCOMPLEENDERECO']);  
            $novoItem->setNrcependereco($row['NRCEPENDERECO']);   
            $novoItem->setDsreferenciaende($row['DSREFERENCIAENDE']); 
            $novoItem->setDsendereco($row['DSENDERECO']);
            $novoItem->setNrimovelendereco($row['NRIMOVELENDERECO']);
            $novoItem->setDtinclusao(DateUtil::getDataAtual());           
            $novoItem->setNrorginclusao($this->hcmParameters->getNrorgTrabalho());         
            $novoItem->setCdoperinclusao($this->hcmParameters->getCdoperador());   
            $novoItem->setNrorgultatu($this->hcmParameters->getNrorgTrabalho());         
            $novoItem->setCdoperultatu($this->hcmParameters->getCdoperador());
            $novoItem->setDtultatu(DateUtil::getDataAtual()); 
            return $novoItem;       
        }
    }
    
    public function setPessoah($pessoah, $row){
        if(is_array($pessoah)){
            foreach($pessoah as $key => $element){
                if ($element->getNrpessoah() == $row['NRPESSOAH']){
                    $pessoah = $element;
              }
            }
        }
        $pessoah->setNrcpfpessoa($row['NRCPFPESSOA']);
        $pessoah->setNrrgpessoa($row['NRRGPESSOA']);
        $pessoah->setCdexrgpessoa($row['CDEXRGPESSOA']);
        $pessoah->setDtexrgpessoa(DateUtil::getDataDeString2($row['DTEXRGPESSOA'], DateUtil::FORMATO_BRASILEIRO, true));
        $pessoah->setDslocalexrgpes($row['DSLOCALEXRGPES']);
        $pessoah->setSgufrgpessoa($row['SGUFRGPESSOA']);
        $pessoah->setNrtitueleipes($row['NRTITUELEIPES']);
        $pessoah->setNrzonaeleipes($row['NRZONAELEIPES']);
        $pessoah->setNrsecaeleipes($row['NRSECAELEIPES']);
        $pessoah->setIdisentituelei($row['IDISENTITUELEI']);
        $pessoah->setDtnascpessoa(DateUtil::getDataDeString2($row['DTNASCPESSOA'], DateUtil::FORMATO_BRASILEIRO, true));
        $pessoah->setNrctpspessoa($row['NRCTPSPESSOA']);
        $pessoah->setNrseriectpspes($row['NRSERIECTPSPES']);
        $pessoah->setSgufctpspes($row['SGUFCTPSPES']);
        $pessoah->setDtctpspessoa(DateUtil::getDataDeString2($row['DTCTPSPESSOA'], DateUtil::FORMATO_BRASILEIRO, true));
        $pessoah->setNrpispaseppes($row['NRPISPASEPPES']);
        $pessoah->setDtinscpispasep(DateUtil::getDataDeString2($row['DTINSCPISPASEP'], DateUtil::FORMATO_BRASILEIRO, true));
        $pessoah->setIdpesnaturaliza($row['IDPESNATURALIZA']);
        $pessoah->setDtnaturalizapes(DateUtil::getDataDeString2($row['DTNATURALIZAPES'], DateUtil::FORMATO_BRASILEIRO, true));
        $pessoah->setCdpais($row['CDPAISNATURALI']);
        $pessoah->setSgestado($row['SGESTADONATURALI']);
        $pessoah->setCdmunicipio($row['CDMUNICIPIONATURALI']);
        $pessoah->setDsexpdocestr($row['DSEXPDOCESTR']);
        $pessoah->setNrclassestrang($row['NRCLASSESTRANG']);
        $pessoah->setDtchegadapais(DateUtil::getDataDeString2($row['DTCHEGADAPAIS'], DateUtil::FORMATO_BRASILEIRO, true));
        $pessoah->setNrdocuestrang($row['NRDOCUESTRANG']);
        $pessoah->setNrorgultatu($this->hcmParameters->getNrorgTrabalho());         
        $pessoah->setCdoperultatu($this->hcmParameters->getCdoperador());
        $pessoah->setDtultatu(DateUtil::getDataAtual()); 
        return $pessoah;
    }
    
    public function setTelefone($telefone, $row, $parcnegocio){
        if($telefone){
            if(is_array($telefone)){
                foreach($telefone as $key => $element){
                    if ($element->getNrcomunicaparc() == $row['CDTELEFONE']){
                        $telefone = $element;
                  }
                }
            }
            
            $telefone->setCdprefixcomuparc($row['PREFIXTELEFONE']);  
            $telefone->setCdcomunicaparc($row['NRTELEFONE']);   
            $telefone->setNrorgultatu($this->hcmParameters->getNrorgTrabalho());         
            $telefone->setCdoperultatu($this->hcmParameters->getCdoperador());
            $telefone->setDtultatu(DateUtil::getDataAtual());  
            return $telefone;     
            
        }else{
            $novoItem = Repositories::COMUNICAPARC;
            $novoItem = new $novoItem();
            $novoItem->setNrcomunicaparc(\HCM\Util\NovoCodigo::geraCodigo($this->hcmParameters->getNrorgTrabalho(), 'COMUNICAPARC', 1, 12, true));
            $novoItem->setNrparcnegocio($parcnegocio);
            $novoItem->setCdformacomu('01');
            $novoItem->setCdprefixcomuparc($row['PREFIXTELEFONE']);  
            $novoItem->setCdcomunicaparc($row['NRTELEFONE']);   
            $novoItem->setNrorg($row['NRORG']);
            $novoItem->setIdativo('S');
            $novoItem->setDtinclusao(DateUtil::getDataAtual());           
            $novoItem->setNrorginclusao($this->hcmParameters->getNrorgTrabalho());         
            $novoItem->setCdoperinclusao($this->hcmParameters->getCdoperador());   
            $novoItem->setNrorgultatu($this->hcmParameters->getNrorgTrabalho());         
            $novoItem->setCdoperultatu($this->hcmParameters->getCdoperador());
            $novoItem->setDtultatu(DateUtil::getDataAtual());   
            return $novoItem;
        }
    }
    
    public function setContCorr($contacorr, $row, $nrparcnegocio){
        if($contacorr){
            if(is_array($contacorr)){
                foreach($contacorr as $key => $element){
                    if ($element->getNrcontcorrparc() == $row['NRCONTCORRPARC']){
                        $contacorr = $element;
                  }
                }
            }
            
            $contacorr->setCdbanco($row['CDBANCO']);  
            $contacorr->setCdagencia($row['CDAGENCIA']);
            $contacorr->setCdcontcorr($row['CDCONTCORR']);
            $contacorr->setNrtpcontcorr($row['NRTPCONTCORR']);
            $contacorr->setNrorgultatu($this->hcmParameters->getNrorgTrabalho());         
            $contacorr->setCdoperultatu($this->hcmParameters->getCdoperador());
            $contacorr->setDtultatu(DateUtil::getDataAtual());    
            return $contacorr;
            
        }else{
            $novoItem = Repositories::CONTCORRPARC;
            $novoItem = new $novoItem();
            $novoItem->setNrcontcorrparc(\HCM\Util\NovoCodigo::geraCodigo($this->hcmParameters->getNrorgTrabalho(), 'CONTCORRPARC', 1, 12, true));         
            $novoItem->setNrparcnegocio($nrparcnegocio);
            $novoItem->setCdbanco($row['CDBANCO']);  
            $novoItem->setCdagencia($row['CDAGENCIA']);
            $novoItem->setCdcontcorr($row['CDCONTCORR']);
            $novoItem->setNrtpcontcorr($row['NRTPCONTCORR']); 
            $novoItem->setNrorg($row['NRORG']);
            $novoItem->setIdativo('S');
            $novoItem->setDtinclusao(DateUtil::getDataAtual());           
            $novoItem->setNrorginclusao($this->hcmParameters->getNrorgTrabalho());         
            $novoItem->setCdoperinclusao($this->hcmParameters->getCdoperador());   
            $novoItem->setNrorgultatu($this->hcmParameters->getNrorgTrabalho());         
            $novoItem->setCdoperultatu($this->hcmParameters->getCdoperador());
            $novoItem->setDtultatu(DateUtil::getDataAtual());   
            return $novoItem;
        }
    }
    
    public function setEmail($email, $row, $parcnegocio){
        if($email){
            if(is_array($email)){
                foreach($email as $key => $element){
                    if ($element->getNrcomunicaparc() == $row['CDEMAIL']){
                        $email = $element;
                  }
                }
            }
             
            $email->setCdcomunicaparc($row['DSEMAIL']);   
            $email->setNrorgultatu($this->hcmParameters->getNrorgTrabalho());         
            $email->setCdoperultatu($this->hcmParameters->getCdoperador());
            $email->setDtultatu(DateUtil::getDataAtual());  
            return $email;     
            
        }else{
            $novoItem = Repositories::COMUNICAPARC;
            $novoItem = new $novoItem();
            $novoItem->setNrcomunicaparc(\HCM\Util\NovoCodigo::geraCodigo($this->hcmParameters->getNrorgTrabalho(), 'COMUNICAPARC', 1, 12, true));
            $novoItem->setNrparcnegocio($parcnegocio);
            $novoItem->setCdformacomu('05');
            $novoItem->setCdcomunicaparc($row['DSEMAIL']);   
            $novoItem->setNrorg($row['NRORG']);
            $novoItem->setIdativo('S');
            $novoItem->setDtinclusao(DateUtil::getDataAtual());           
            $novoItem->setNrorginclusao($this->hcmParameters->getNrorgTrabalho());         
            $novoItem->setCdoperinclusao($this->hcmParameters->getCdoperador());   
            $novoItem->setNrorgultatu($this->hcmParameters->getNrorgTrabalho());         
            $novoItem->setCdoperultatu($this->hcmParameters->getCdoperador());
            $novoItem->setDtultatu(DateUtil::getDataAtual());   
            return $novoItem;
        }
    }
    
    public function validaValorMonetario($valor){
        if(!empty($valor)){    
            $valor = str_replace('.','',$valor);
            $valor = str_replace(',','.',$valor);
            return $valor;
        }
        return null;
           
    }
    
}