<?php

namespace HCM\Geral\Services;

use Doctrine\ORM\EntityManager;
use HCM\Util\HCMParameters;
use HCM\Util\Messages;
use HCM\Util\Repositories;
use Zeedhi\Framework\DTO\Response\Notification;
use Zeedhi\Framework\DTO\Response\Error;

class HcmManualService {
    
	const NRPARCNEGOCIO_DOCUMENTACAO = '191007531'; //'191006868';
	const NRORG_DOCUMENTACAO         = '0'; //'20';
    const DESCRIPTION_FULL           = "Tela: nmTela\r\nPágina: nmPagina\r\nNome do arquivo de manual: nmManual\r\n\nOperador: cdOper - nmOper\r\nOrgnaização: nrOrg"; //Vide controller do front
    const DESCRIPTION_PKVALUES       = "{\"NRORG\":\"nrOrg\", TELA: nmTela, PAGINA: nmPagina}";
    const INSERT_tku_log             = 'insert into TKU_LOG (TKU_LOG_ID,CREATED,DESCRIPTION,TABLENAME,PKVALUES,DATADIFF,EXTENDED_DATA,IP,TYPE,USERNAME,NRORG) values (:TKU_LOG_ID,:CREATED,:DESCRIPTION,:TABLENAME,:PKVALUES,SUBSTR(:DATADIFF,1,2000),:EXTENDED_DATA,:IP,:TYPE,:USERNAME,:NRORG)';

    protected $entityManager;
    protected $nrorg;
    protected $cdoperador;
    protected $nmoperador;
    protected $tku_log_row = array('CREATED'=>null,'DESCRIPTION'=>null,'TABLENAME'=>null,'PKVALUES'=>null,'DATADIFF'=>null,'EXTENDED_DATA'=>null,'IP'=>null,'TYPE'=>null,'USERNAME'=>null,'NRORG'=>null);
    
    
    public function __construct(EntityManager $entityManager, HCMParameters $hcmParameters) {
        $this->entityManager = $entityManager;
        $this->nrorg         = $hcmParameters->getNrorgTrabalho();
        $this->cdoperador    = $hcmParameters->getCdoperador();
        $this->nmoperador    = $hcmParameters->getNmoperador();
    }
    
    
    private function getPathsManual($nmManual) {
        $nmManual .= '.';
        
        $params = array(
            'nrorg'             => self::NRORG_DOCUMENTACAO,
            'nrparcnegocio'     => self::NRPARCNEGOCIO_DOCUMENTACAO
            );
        $anexos = $this->entityManager->getRepository(Repositories::GPE_ANEXOS)->findBy($params);
        
        $paths = array();
        
        foreach($anexos as $anexo) {
            $nmanexo = strtolower($anexo->getNmanexo());
            $dspath  =            $anexo->getDspath();
            
            if(strpos($nmanexo, $nmManual) === 0)
                $paths[] = array('nmanexo' => $nmanexo, 'dspath' => $dspath);
        }
        
        return $paths;
    }
    
    
    private function getDescription($info, $source) {
        foreach($info as $key => $val) {
            $source = str_replace($key, $val, $source);
        }
        return $source;
    }
    
    
    private function setAdditionalInfo(&$info) {
        $info['nmOper'] = $this->nmoperador;
        $info['cdOper'] = $this->cdoperador;
        $info['nrOrg' ] = $this->nrorg;
    }
    
    
    private function setLog($info) {
        $this->setAdditionalInfo($info);
        $this->tku_log_row['TABLENAME'] = 'HCM_DOCUMENTACAO';
        $this->tku_log_row['DATADIFF' ] = $this->getDescription($info, self::DESCRIPTION_FULL);
        $this->tku_log_row['PKVALUES' ] = $this->getDescription($info, self::DESCRIPTION_PKVALUES);
        $this->tku_log_row['USERNAME' ] = $this->nmoperador;
        $this->tku_log_row['TYPE'     ] = "I";
        $this->tku_log_row['NRORG'    ] = $this->nrorg;
        
        try{
            $std = $this->entityManager->getConnection()->prepare('SELECT MAX(TKU_LOG_ID) + 1 AS TKU_LOG_ID FROM TKU_LOG');
            $std->execute();
            $result = $std->fetchAll();
            
            $this->tku_log_row['CREATED'   ] = date('d/m/Y H:i:s');
            $this->tku_log_row['IP'        ] = getHostByName(getHostName());
            $this->tku_log_row['TKU_LOG_ID'] = $result[0]['TKU_LOG_ID'];
            
            $this->entityManager->getConnection()->prepare(self::INSERT_tku_log)->execute($this->tku_log_row);
        } catch (\Exception $e) {
            $error = "Error on log generation: ".$e->getMessage();
            throw new \Exception($error);
        }
    }
    
    
    public function getHcmManual($row) {
        $paths = $this->getPathsManual($row['nmManual']);
        
        if(count($paths) == 0) {
            /*tratativa de e-mail - se for usar...*/
            $this->setLog($row);
            throw new \Exception("HCM_MANUAL_NO_MANUAL"); //retorna msg de indisponibilidade de manual
        }
        
        return $paths;
    }

    
    /*
    private function sendMail($info) {
        $mail = $this->hcmParameters->returnParamsSmtp();
        $content = array(
            "SUBJECT"                 => "HCM Documnetação - Manual",
            "STRING_SUPERIOR_DIREITA" => "",
            "CONTENT_BODY"            => $info['nmTela'] . ' - ' . $info['nmPagina'] . '\n\n' . $info['nmManual']
        );
    }*/
}