<?php
namespace HCM\PTO\Controllers;

use Zeedhi\Framework\Controller\Crud;
use Zeedhi\Framework\DataSource\Manager;
use Zeedhi\Framework\DataSource\ParameterBag;
use Zeedhi\Framework\DataSource\FilterCriteria;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DTO\Request;
use HCM\Util\DateUtil;

class AuditoriaApuracaoController extends Crud {

    protected $dataSourceGetAuditoriaApuracao = 'ptoAuditoraApuracao_getAuditoriaApuracao';
    protected $dataSourceSetAuditoriaApuracao = 'ptoAuditoraApuracao_setAuditoriaApuracao';

    protected $parameterBagColumns = array('NRORG', 'NRTIPOVINCULOM');

    public function __construct (Manager $dataSourceManager, ParameterBag $parameterBag){
        $this->parameterBag    = $parameterBag;
        parent::__construct($dataSourceManager);
    }

    public function getAuditoriaApuracao (DTO\Request\Filter $request, DTO\Response $response) {
        try{
            $filterData = $request->getFilterCriteria();
            $filterData->setDataSourceName($this->dataSourceGetAuditoriaApuracao);
            $newFilterData = $this->populateParameterBag($filterData);
            $dataSet = $this->dataSourceManager->findBy($newFilterData); 
            $response->addDataSet($dataSet);
        } catch(\Exception $e) {
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }

    public function setAuditoriaApuracao (DTO\Request\DataSet $request, DTO\Response $response) {
        $this->dataSourceName = $this->dataSourceSetAuditoriaApuracao;
        try{
            foreach($request->getDataSet()->getRows() as $row) {
                if($row['__is_new'] === true){
                    $row['DTINCLUSAO'] = $row['DTATUAL'];
                    $row['CDOPERINCLUSAO'] = $row['CDOPERADOR_LOG'];
                    $row['NRORGINCLUSAO'] = $row['NRORGTRAB'];
                    $row['DTULTATU'] = $row['DTATUAL'];
                    $row['CDOPERULTATU'] = $row['CDOPERADOR_LOG'];
                    $row['NRORGULTATU'] = $row['NRORGTRAB'];
                    $row['NRPERIODOAPURACAOAUDIT'] = \HCM\Util\NovoCodigo::geraCodigo( $row['NRORGTRAB'], 'PTO_PERIODOAPURACAOAUDIT', 1, 12, true);
                } else {
                    $row['DTULTATU'] = $row['DTATUAL'];
                    $row['CDOPERULTATU'] = $row['CDOPERADOR_LOG'];
                    $row['NRORGULTATU'] = $row['NRORGTRAB'];
                }
                
                $row['NRORG'] = $row['NRORGTRAB'];
            }
            parent::save($request, $response);
        } catch(\Exception $e) {
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }

    public function deleteAuditoriaApuracao (DTO\Request\Row $row, DTO\Response $response) {
        try{
            $dataSet = new DataSet($this->dataSourceSetAuditoriaApuracao, array($row->getRow()));
            $deletedRows = $this->dataSourceManager->delete($dataSet);

            $response->addDataSet(new DataSet($this->dataSourceSetAuditoriaApuracao, array('type' => 'success', $deletedRows)));
        } catch(\Exception $e) {
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }

    protected function processConditionValue($condition) {
        return $condition['value'];
    }

    protected function populateParameterBag(FilterCriteria $filterCriteria) {

        $conditions = array();
        foreach ($filterCriteria->getConditions() as $condition) {
            $columnName = $condition['columnName'];
            if (in_array($columnName, $this->parameterBagColumns)) {
                $this->parameterBag->set($columnName, $this->processConditionValue($condition));
            } else {
                $conditions[] = $condition;
            }
        }

        $newFilterCriteria = new FilterCriteria(
            $filterCriteria->getDataSourceName(),
            $conditions,
            $filterCriteria->getPage(),
            $filterCriteria->getPageSize()
        );


        return $newFilterCriteria;
    }
}