<?php

namespace HCM\PTO\Controllers;

use Zeedhi\Framework\Controller\Crud;
use Zeedhi\Framework\DataSource\Manager;
use Zeedhi\Framework\DataSource\ParameterBag;
use Zeedhi\Framework\DataSource\FilterCriteria;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Request\Row;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DTO\Request;
use HCM\Util\HCMParameters;
use HCM\Util\DateUtil;

class ProgBancoHorasController extends Crud {

    protected $parameterBagColumns = array('NRORG','NRORGPADRAO', 'NRBANCOHORAS');

    public function __construct (Manager $dataSourceManager, ParameterBag $parameterBag, HCMParameters $hcmParameters){
        $this->parameterBag = $parameterBag;
        $this->hcmParameters   = $hcmParameters;
        parent::__construct($dataSourceManager);
    }

    public function getProgBancoHoras (DTO\Request\Filter $request, DTO\Response $response) {
        try{
            
            $filterData = $request->getFilterCriteria();
            $filterData->setDataSourceName($this->dataSourceName = "getProgBancoHoras");
            $newFilterData = $this->populateParameterBag($filterData);
            $dataSet = $this->dataSourceManager->findBy($newFilterData); 
            $response->addDataSet($dataSet);
        } catch(\Exception $e) {
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }

    protected function processConditionValue($condition) {
        return $condition['value'];
    }
    protected function populateParameterBag(FilterCriteria $filterCriteria) {

        $conditions = array();
        foreach ($filterCriteria->getConditions() as $condition) {
            $columnName = $condition['columnName'];
            if (in_array($columnName, $this->parameterBagColumns)) {
                $this->parameterBag->set($columnName, $this->processConditionValue($condition));
            } else {
                $conditions[] = $condition;
            }
        }
        $newFilterCriteria = new FilterCriteria(
            $filterCriteria->getDataSourceName(),
            $conditions,
            $filterCriteria->getPage(),
            $filterCriteria->getPageSize()
        );
        return $newFilterCriteria;
    }
    
    public function setProgBancoHoras(DTO\Request\DataSet $request, DTO\Response $response) {
        
        try{
            $this->dataSourceName = "PtoBancohorasprog_setProgramBancoHoras";
            foreach($request->getDataSet()->getRows() as &$row) {
                if(array_key_exists('NRBANCOHORASPROG', $row)){
                    if(empty($row['NRBANCOHORASPROG'])){
                        $row['NRBANCOHORASPROG'] = \HCM\Util\NovoCodigo::geraCodigo($row['NRORG'], 'PTO_BANCOHORASPROG', 1, 12, true);
                    }
                } else {
                    $row['NRBANCOHORASPROG'] = \HCM\Util\NovoCodigo::geraCodigo($row['NRORG'], 'PTO_BANCOHORASPROG', 1, 12, true);
                }

                if(!array_key_exists('NRTIPOPROGOCORRENCIA', $row)){
                    $row['NRTIPOPROGOCORRENCIA'] = null;
                }
                if(!array_key_exists('NRSITUFREQUENCIA', $row)){
                    $row['NRSITUFREQUENCIA'] = null;
                }
                if(!array_key_exists('NRSITUFREQGATILHO', $row)){
                    $row['NRSITUFREQGATILHO'] = null;
                }
                
            }
            parent::save($request, $response);
        } catch(\Exception $e) {
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
     public function delete(DTO\Request\DataSet $request, DTO\Response $response){
        try{
            $this->dataSourceName = "PtoBancohorasprog_setProgramBancoHoras";
            parent::delete($request, $response);
        } catch(\Exception $e) {
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }
}