<?php
namespace HCM\TRE\Services;

use HCM\TRE\Repository\TreinamentoRepository;
use Doctrine\ORM\EntityManager;
use HCM\Util\HCMParameters;
use HCM\Util\Messages;
use HCM\Util\DateUtil;
use HCM\Util\Repositories;

class TreinamentoService{
    
    protected $entityManager;
    protected $hcmParameters;
    
    public function __construct(EntityManager $entityManager, HCMParameters $hcmParameters,\HCM\TRE\Repository\TreinamentoRepository $treinamentoRepository) {
        $this->entityManager = $entityManager;
        $this->hcmParameters = $hcmParameters;
        $this->treinamentoRepository = $treinamentoRepository;
    }
    
    public function setDocumento($dataset) {
        if (array_key_exists('DSREFARQUIVOTRE', $dataset)) {
            if (is_array($dataset['DSREFARQUIVOTRE'])) {
                $arquivos = $dataset['DSREFARQUIVOTRE'];            
                foreach ($arquivos as $fileData) {
                    $type = null;

                    if( isset($fileData["name"]) && !empty($fileData["name"]) && strlen($fileData["name"]) > 0 )
                        $type = explode('.', $fileData["name"])[1];
                    else if( isset($fileData["path"]) && !empty($fileData["path"]) && strlen($fileData["path"]) > 0 )
                        $type = explode('.', $fileData["path"])[1];
                    
                    
                    $nrdocumento = \HCM\Util\NovoCodigo::geraCodigo($dataset['NRORG'], 'GPE_DOCUMENTOTRE', 1, 12, true);
                    $this->treinamentoRepository->setDocumento($this->hcmParameters->getNrorgTrabalho(),$nrdocumento,$dataset['NRTREINAMENTO'],$fileData['name'],$dataset['DSREFDOCUMENTOTRE'],$fileData["path"],$type,DateUtil::getDataAtual(),$this->hcmParameters->getCdoperador());
                }
            }
            return true;
        } else {
            return false;
        }
    }
    
    public function validaCustoTreinamento($nrorg,$nrtreinamento,$custo_pl,$custo_real = null,$real = false){
        $despesas = $this->treinamentoRepository->getDespesas($nrorg,$nrtreinamento);
        $soma_pl = 0;
        $soma_real = 0;
        if(empty($despesas))
            $return_pl = true;
        else{
            foreach ($despesas as &$row) {
                $soma_pl += $row['VRPLANEJADODESPTRE'];
                $soma_real += is_numeric($row['VRREALIZADODESPTRE'])?$row['VRREALIZADODESPTRE']:null;
            }
            if($custo_pl == $soma_pl)
                $return_pl = true;
            else 
                $return_pl = false;
        }
        if($real){
            if(empty($despesas))
                $return_real = true;
            else
                if($custo_real == $soma_real)
                    $return_real = true;
                else 
                    $return_real = false;
        return  array(
        "PLANEJADO"=>$return_pl,
        "REAL"=>$return_real
        );
        }
        else{
        return $return_pl;
        }
    }
    
    public function validaParticipantes($nrorg,$nrtreinamento,$nrparticipatre,$nrparcnegocio){
        return $this->treinamentoRepository->validaParticipantes($nrorg,$nrtreinamento,$nrparticipatre,$nrparcnegocio);
    }
    
    public function listaLocais($nrorg,$nrtreinamento){
        $locais_list = $this->treinamentoRepository->getLocais($nrorg,$nrtreinamento);
        if(empty($locais_list))
            return "Indefinido";
        if(count($locais_list) == 1)
            return $locais_list[0]['NMESTRUTURAM'];//retorna "Local1"
        if(count($locais_list) == 2)
            return $locais_list[0]['NMESTRUTURAM']." e ".$locais_list[1]['NMESTRUTURAM'];// retorna "Local1 e Local2"
        $message = array_shift($locais_list)['NMESTRUTURAM'];
        $last = array_pop($locais_list);
        foreach($locais_list as &$local){
            $message .= ", ".$local['NMESTRUTURAM'];
        }
        return $message." e ".$last['NMESTRUTURAM'];//retorna "Local1, Local2, ... e LocalN
    }
    
    public function validaConclusao($nrorg,$nrtreinamento){
        $participante_list = $this->treinamentoRepository->getParticipantes($nrorg,$nrtreinamento);
        $return_arr = array();
        if(empty($participante_list))
            return array(false,$participante_list);
        foreach ($participante_list as $participante) {
            if( !isset($participante['VRNOTAPARTICIPATRE']) || !isset($participante['VRPERFREQUENCIATRE']) || is_null($participante['VRNOTAPARTICIPATRE']) || is_null($participante['VRPERFREQUENCIATRE']))
                array_push($return_arr,$participante['NMPRINCIPALPARC']);
        }
        return array(empty($return_arr),$return_arr);
    }

    public function getParticipantes($nrorg,$nrtreinamento){
        return $this->treinamentoRepository->getParticipantes($nrorg,$nrtreinamento);
    }
    public function getDocumentos($nrorg,$nrtreinamento){
        return $this->treinamentoRepository->getDocumentos($nrorg,$nrtreinamento);
    }
    public function getDespesas($nrorg,$nrtreinamento){
        return $this->treinamentoRepository->getDespesas($nrorg,$nrtreinamento);
    }
    public function getLocal($nrorg,$nrtreinamento){
        return $this->treinamentoRepository->getLocal($nrorg,$nrtreinamento);
    }
    public function getMaterial($nrorg,$nrtreinamento){
        return $this->treinamentoRepository->getMaterial($nrorg,$nrtreinamento);
    }
    public function getAvaliacao($nrorg,$nrtreinamento){
        return $this->treinamentoRepository->getAvaliacao($nrorg,$nrtreinamento);
    }
    public function validaDelete($nrorg,$nrtreinamento){
        return $this->treinamentoRepository->validaDelete($nrorg,$nrtreinamento);
    }
    public function getOperador($nrorg,$nrparcnegocio){
        return $this->treinamentoRepository->getOperador($nrorg,$nrparcnegocio);
    }
    public function getParcNegocioByCdoperador($nrorg,$cdoperador){
        return $this->treinamentoRepository->getParcNegocioByCdoperador($nrorg,$cdoperador);
    }
    public function getParcNegocio($nrorg,$nrparcnegocio){
        return $this->treinamentoRepository->getParcNegocio($nrorg,$nrparcnegocio);
    }
    public function getCurso($nrorg,$nrcurso){
        return $this->treinamentoRepository->getCurso($nrorg,$nrcurso);
    }
    public function validaPerfil($nrorg,$nrperfacesso,$operador){
        if(empty($nrperfacesso))
            return true;
        return $this->treinamentoRepository->validaPerfil($nrorg,$nrperfacesso,$operador);
    }
    public function aprovaTreinamento($nrorg,$nrtreinamento,$idEstado,$obsAprov,$parceiro,$data){
        $this->treinamentoRepository->aprovaTreinamento($nrorg,$nrtreinamento,$idEstado,$obsAprov,$parceiro,$data);
    }
    public function executaTreinamento($nrorg,$nrtreinamento,$data){
        $this->treinamentoRepository->executaTreinamento($nrorg,$nrtreinamento,$data);
    }
    public function cancelaTreinamento($nrorg,$nrtreinamento,$data){
        $this->treinamentoRepository->cancelaTreinamento($nrorg,$nrtreinamento,$data);
    }
    public function atestaEficacia($nrorg,$nrtreinamento,$idEficacia,$dsEficacia){
        $this->treinamentoRepository->atestaEficacia($nrorg,$nrtreinamento,$idEficacia,$dsEficacia,($idEficacia == 'S')?true:false);
    }
    public function concluiTreinamento($nrorg,$nrtreinamento,$data){
        $this->treinamentoRepository->concluiTreinamento($nrorg,$nrtreinamento,$data);
    }

    public function CadastroAutomatico($nrorg,$nrtreinamento,$nrcurso,$requerido,$desejado,$valida,$nrestrutsind,$nrestrutlegal,$nrestrutgeren,$nrvinculom){
        $curso = $this->treinamentoRepository->getCurso($nrorg,$nrcurso);
        $return = 0;
        $nrParcnegocios_list = array();
        if(!empty($nrestrutsind) || !empty($nrestrutlegal) || !empty($nrestrutgeren) || !empty($nrvinculom)){
            $parceiros_list = $this->treinamentoRepository->getParceirosCadastroBasico($nrorg,$this->hcmParameters->getDtCompetencia(),$nrestrutsind,$nrestrutlegal,$nrestrutgeren,$nrvinculom);
            
            foreach ($parceiros_list as $value)
                array_push($nrParcnegocios_list,$value['NRPARCNEGOCIO']);
        }
        if($requerido || $desejado){
            $Participantes_perfil = array();
            foreach ($this->treinamentoRepository->getItPerfilCurso($nrorg,$nrcurso) as $itperfil) {
                $perfilVinc_list = array();
                $perfilEstrut_list = array();
                $perfilOcupa_list = array();
                if($requerido){
                    $perfilVinc_list = array_merge($perfilVinc_list,$this->treinamentoRepository->getPerfilCursoVinculom($nrorg,$itperfil['NRPERFILCURSO'],'REQUERIDO'));
                    $perfilEstrut_list = array_merge($perfilEstrut_list,$this->treinamentoRepository->getPerfilCursoEstruturam($nrorg,$itperfil['NRPERFILCURSO'],'REQUERIDO'));
                    $perfilOcupa_list = array_merge($perfilOcupa_list,$this->treinamentoRepository->getPerfilCursoOcupacao($nrorg,$itperfil['NRPERFILCURSO'],'REQUERIDO'));
                }
                if($desejado){
                    $perfilVinc_list = array_merge($perfilVinc_list,$this->treinamentoRepository->getPerfilCursoVinculom($nrorg,$itperfil['NRPERFILCURSO'],'DESEJAVEL'));            
                    $perfilEstrut_list = array_merge($perfilEstrut_list,$this->treinamentoRepository->getPerfilCursoEstruturam($nrorg,$itperfil['NRPERFILCURSO'],'DESEJAVEL'));            
                    $perfilOcupa_list = array_merge($perfilOcupa_list,$this->treinamentoRepository->getPerfilCursoOcupacao($nrorg,$itperfil['NRPERFILCURSO'],'DESEJAVEL'));            
                }
                foreach ($perfilVinc_list as $vinculo)
                    array_push($Participantes_perfil,$this->treinamentoRepository->getParcNegocioByNrvinculom($vinculo['NRORG'],$vinculo['NRVINCULOM'],$this->hcmParameters->getDtCompetencia()));
                foreach ($perfilEstrut_list as $estrutura) {
                    $est = $this->treinamentoRepository->getParcNegocioByNrestruturam($estrutura['NRORG'],$estrutura['NRESTRUTURAM'],$this->hcmParameters->getDtCompetencia());
                    if(!is_null($est))
                        $Participantes_perfil = array_merge($Participantes_perfil,$est);
                }
                foreach ($perfilOcupa_list as $ocupacao) {
                    $ocup = $this->treinamentoRepository->getParcNegocioByNrocupacaom($ocupacao['NRORG'],$ocupacao['NROCUPACAOM'],$this->hcmParameters->getDtCompetencia());
                    if(!is_null($ocup))
                        $Participantes_perfil = array_merge($Participantes_perfil,$ocup);
                }
            }
        $nrParc_perfil = array();
        foreach ($Participantes_perfil as $value)
            array_push($nrParc_perfil,$value['NRPARCNEGOCIO']);
        if(empty($nrParcnegocios_list))
            $nrParcnegocios_list = $nrParc_perfil;
        else 
            $nrParcnegocios_list = array_intersect($nrParcnegocios_list,$nrParc_perfil);
        }
        if($valida){
            $valida = $this->treinamentoRepository->getParcNegocioByDtValidade($nrorg,$nrcurso,$this->hcmParameters->getUltimoDiaMes(),$this->hcmParameters->getDtCompetencia());
            $nrParc_val = array();
            foreach ($valida as $value) 
                array_push($nrParc_val,$value['NRPARCNEGOCIO']);
            if(empty($nrParcnegocios_list))
                $nrParcnegocios_list = $nrParc_val;
            else 
                $nrParcnegocios_list = array_intersect($nrParcnegocios_list,$nrParc_val);
        }
        
        $nrParcnegocios_list = array_unique($nrParcnegocios_list);
        
        foreach($nrParcnegocios_list as $nrparcnegocio){
            if($this->treinamentoRepository->insereParticipante($nrorg,$nrtreinamento,$nrparcnegocio,$this->hcmParameters->getDataAtual(),$this->hcmParameters->getCdoperador()))
                $return++;
        }
        
        return $return;
    }
    
    public function deletaTodosParticipantes($nrorg,$nrtreinamento){
        $this->treinamentoRepository->deletaTodosParticipantes($nrorg,$nrtreinamento);
    }
    
    public function calculaResultado($nrorg,$nrtreinamento,$criterio){
        $participante_list = $this->treinamentoRepository->getParticipantes($nrorg,$nrtreinamento);
        $faixa_list = $this->treinamentoRepository->getFaixaCritResult($nrorg,$criterio);
        foreach ($participante_list as $participante) {
            foreach ($faixa_list as $faixa) {
                switch($faixa['IDFAIXACRIRESUL']){
                    case 'MAIOR_QUE':
                        if($participante['VRNOTAPARTICIPATRE'] > $faixa['VRINIFAIXARESUL'])
                            $tipo = $faixa['CDTIPORESU'];
                        break;
                    case 'MENOR_QUE':
                        if($participante['VRNOTAPARTICIPATRE'] < $faixa['VRINIFAIXARESUL'])
                            $tipo = $faixa['CDTIPORESU'];
                        break;
                    case'ENTRE':
                        if($participante['VRNOTAPARTICIPATRE'] > $faixa['VRINIFAIXARESUL'] && $participante['VRNOTAPARTICIPATRE'] < $faixa['VRFINFAIXARESUL'])
                            $tipo = $faixa['CDTIPORESU'];
                        break;
                }
            }
            
            $this->treinamentoRepository->insereResultadoParticipante($nrorg,$nrtreinamento,$participante['NRPARTICIPATRE'],$tipo);
        }
    }
    
    public function atualizarValorTreinamento($nrTreinamento){
        
        $totalDespesasReal = $totalDespesasPlan = 0;
        $despesas = $this->entityManager->getRepository(Repositories::GPE_DESPESATRE)->findBy( 
            [ 
             'nrorg'         => $this->hcmParameters->getNrorgTrabalho(),
             'nrtreinamento' => $nrTreinamento,
            ]
        );

        $treinamento = $this->entityManager->getRepository(Repositories::GPE_TREINAMENTO)->findOneBy( 
            [ 
             'nrorg'         => $this->hcmParameters->getNrorgTrabalho(),
             'nrtreinamento' => $nrTreinamento,
            ]
        );
        
        foreach ($despesas as $despesa) {
            $totalDespesasReal += $despesa->getVrrealizadodesptre();
            $totalDespesasPlan += $despesa->getVrplanejadodesptre();
        }

        $treinamento->setVrcustorealtreinamento($totalDespesasReal);
        $treinamento->setVrcustoplatreinamento($totalDespesasPlan);
        
        $this->entityManager->persist($treinamento);
        $this->entityManager->flush();
        
        return array('TOTALDESPESASREAL'=>$totalDespesasReal, 'TOTALDESPESASPLAN'=>$totalDespesasPlan);
        
    }
    
}